@@ -3,6 +3,7 @@ import tornado.ioloop
 import tornado.web
 import tornado.auth
 import os
+import re
 import uuid
 import tornado.websocket
 from otter_service_stdalone import fs_logging as log
@@ -37,7 +38,7 @@ class WebSocketHandler(tornado.websocket.WebSocketHandler):
             if user_id not in session_callbacks:
                 session_callbacks[user_id] = tornado.ioloop.PeriodicCallback(lambda: self.send_results(user_id), 1000)
                 session_callbacks[user_id].start()
-    
+
     def on_message(self, message):
         pass  # No action needed on incoming message
 
@@ -209,10 +210,11 @@ class Download(BaseHandler):
                         zipF.write(f"{file_path}", f_path, compress_type=ZIP_DEFLATED)
                 read_me = os.path.join(os.path.dirname(__file__), "static_files", "README_DO_NOT_DISTRIBUTE.txt")
                 zipF.write(read_me, "README_DO_NOT_DISTRIBUTE.txt", compress_type=ZIP_DEFLATED)
-
+            
+            download_label = f"{'-'.join(download_code.split('-')[:-5])}-results.zip"
             self.set_header('Content-Type', 'application/octet-stream')
             self.set_header("Content-Description", "File Transfer")
-            m = f"attachment; filename=results-{download_code}.zip"
+            m = f"attachment; filename={download_label}"
             self.set_header('Content-Disposition', m)
             with open(f"{directory}/results.zip", 'rb') as f:
                 try:
@@ -251,9 +253,11 @@ class Upload(BaseHandler):
         results_path = str(uuid.uuid4())
         autograder = self.request.files['autograder'][0] if "autograder" in files else None
         notebooks = self.request.files['notebooks'][0] if "notebooks" in files else None
-        log.write_logs(results_path, "Step 1: Upload accepted", "", "debug", log_debug)    
         if autograder is not None and notebooks is not None:
+            log.write_logs(results_path, "Step 1: Upload accepted", "", "debug", log_debug)
             notebooks_fname = notebooks['filename']
+            sanitized_filename = re.sub(r"[ ,./\\\[\]{}()]]", "", os.path.splitext(notebooks_fname)[0])
+            results_path = f"{sanitized_filename}-{results_path}"
             notebooks_extn = os.path.splitext(notebooks_fname)[1]
             if notebooks_extn == ".zip":
                 notebooks_name = results_path + notebooks_extn
@@ -261,7 +265,9 @@ class Upload(BaseHandler):
                 notebooks_name = f"{results_path}/{notebooks_fname}"
                 os.mkdir(f"{__UPLOADS__}/{results_path}")
             autograder_fname = autograder['filename']
-            autograder_extn = os.path.splitext(autograder_fname)[1]
+            arr_autograder_fname = os.path.splitext(autograder_fname)
+            autograder_orig_name = arr_autograder_fname[0]
+            autograder_extn = arr_autograder_fname[1]
             autograder_name = str(uuid.uuid4()) + autograder_extn
             if not os.path.exists(__UPLOADS__):
                 os.mkdir(__UPLOADS__)
@@ -275,12 +281,13 @@ class Upload(BaseHandler):
             m = "Step 3A: Uploaded autograder.zip files written to disk - now checking otter version"
             log.write_logs(results_path, m, f"Results Code: {results_path}", "debug", log_debug)
             if not otter_version_correct(auto_p):
-                m = "Step 3A-1: autograder.zip is wrong version of otter-grader; must be >= 5.5.0"
+                m = "Step 3A-1: autograder.zip is wrong version of otter-grader; must be >= 6.0.4"
                 log.write_logs(results_path, m, f"Results Code: {results_path}", "debug", log_debug)
-                m = "You need to make sure the autograder.zip uses otter-grader version >=5.5.0. BUT you do not need "
-                m += "to re-generate your autograder.zip; un-archive autograder.zip and change the version in either "
-                m += "requirements.txt or environmental.yaml depending on the version of otter-grader the autograder.zip "
-                m += "is created with."
+                m = "If you are teaching Data 8, please get the latest autograder.zips from materials-sp22-private. "
+                m += "If you are NOT teaching Berkeley's Data 8, you need to make sure the autograder.zip uses "
+                m += "otter-grader version >=6.0.4; due to breaking changes in "
+                m += "otter-grader dependencies you need to run otter assign with otter-grader >= 6.0.4 to generate working "
+                m += "solution files(autograder.zips)."
                 self.render("index.html", message=m)
             else:
                 fh = open(notebooks_path, 'wb')
@@ -293,11 +300,11 @@ class Upload(BaseHandler):
                 try:
                     session_queues[user_id][results_path] = Queue()
                     session_messages[user_id][results_path] = []
-                    await g.grade(auto_p, notebooks_path, results_path, session_queues[user_id].get(results_path))
+                    await g.grade(auto_p, notebooks_path, autograder_orig_name, results_path, session_queues[user_id].get(results_path))
                 except Exception as e:
                     log.write_logs(results_path, "Grading Problem", str(e), "error", log_error)
         else:
-            m = "Step 2b: Uploaded Files not given"
+            m = "Step 1: Uploaded Files not given"
             log.write_logs(results_path, m, "", "debug", log_debug)
             m = "It looks like you did not set the notebooks or autograder.zip or both!"
             self.render("index.html", message=m)
